==> hmr_daemon-0.1-py2.py3-none-any.whl: hmr_daemon.py <==
from pathlib import Path
from sys import argv
from threading import Event, Thread
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from reactivity.hmr.core import BaseReloader

    original_init = BaseReloader.__init__
else:
    original_init = None


def patch():
    global original_init

    from functools import wraps

    from reactivity.hmr.core import BaseReloader

    @wraps(original_init := BaseReloader.__init__)
    def wrapper(*args, **kwargs):
        if not disabled:
            shutdown_event.set()
            BaseReloader.__init__ = original_init
        original_init(*args, **kwargs)

    BaseReloader.__init__ = wrapper


def main():
    from reactivity.hmr.core import SyncReloader

    class Reloader(SyncReloader):
        def __init__(self):
            global disabled

            disabled = True
            super().__init__("")
            disabled = False

            self.error_filter.exclude_filenames.add(__file__)

        def start_watching(self):
            if shutdown_event.is_set():
                return

            from watchfiles import PythonFilter, watch

            if shutdown_event.is_set():
                return

            for events in watch(".", watch_filter=PythonFilter(), stop_event=shutdown_event):
                self.on_events(events)

    if not shutdown_event.is_set():
        Reloader().start_watching()


shutdown_event = Event()

patch_first = "hmr" in Path(argv[0]).name

disabled = False

if patch_first:
    patch()
else:
    Thread(target=lambda: [patch(), main()], daemon=True).start()

==> hmr_daemon-0.1.1-py2.py3-none-any.whl: hmr_daemon.py <==
from os import getenv
from pathlib import Path
from sys import argv
from threading import Event, Thread
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from reactivity.hmr.core import BaseReloader

    original_init = BaseReloader.__init__
else:
    original_init = None


def patch():
    global original_init

    from functools import wraps

    from reactivity.hmr.core import BaseReloader

    @wraps(original_init := BaseReloader.__init__)
    def wrapper(*args, **kwargs):
        if not disabled:
            shutdown_event.set()
            BaseReloader.__init__ = original_init
        original_init(*args, **kwargs)

    BaseReloader.__init__ = wrapper


def main():
    from reactivity.hmr.core import SyncReloader

    class Reloader(SyncReloader):
        def __init__(self):
            global disabled

            disabled = True
            super().__init__("", excludes=(venv,) if (venv := getenv("VIRTUAL_ENV")) else ())
            disabled = False

            self.error_filter.exclude_filenames.add(__file__)

        def start_watching(self):
            if shutdown_event.is_set():
                return

            from watchfiles import PythonFilter, watch

            if shutdown_event.is_set():
                return

            for events in watch(".", watch_filter=PythonFilter(), stop_event=shutdown_event):
                self.on_events(events)

    if not shutdown_event.is_set():
        Reloader().start_watching()


shutdown_event = Event()

patch_first = "hmr" in Path(argv[0]).name

disabled = False

if patch_first:
    patch()
else:
    Thread(target=lambda: [patch(), main()], daemon=True).start()
